@@ -97,7 +97,8 @@ init_mem()
 }
 
 /*
- * Initialize the global variables.
+ * Initialize some important global variables to their defaults.
+ * This is called on startup and by process() to reset the global flags to the default state.
  */
 void
 init_gvars()
@@ -121,14 +122,13 @@ init_gvars()
 }
 
 /*
- * Clean up when processing is unexpectedly
- * interrupted or terminated.
+ * Clean up when processing is unexpectedly interrupted or terminated.
  */
 void
 clean_up()
 {
-	init_gvars();
-	if (gfp != stdout) {
+	init_gvars();		/* reset the global variables to the default */
+	if (gfp != stdout) {	/* reset the output file to standard output */
 #if	!SECURE
 		fclose(gfp);
 #endif
@@ -137,7 +137,8 @@ clean_up()
 }
 
 /*
- * Register all sign variables in all equation spaces.
+ * Register all sign variables in all equation spaces
+ * so that the next sign variables returned by next_sign() will be unique.
  */
 void
 set_sign_array()
@@ -279,12 +280,16 @@ next_espace()
 }
 
 /*
- * Copy equation number "src" to equation number "dest".
+ * Copy equation space "src" to equation space "dest".
  */
 void
 copy_espace(src, dest)
-int	src, dest;
+int	src, dest;	/* indices */
 {
+	if (src == dest) {
+		error("Internal error: copy_espace(src, dest) source and destination the same.");
+		return;
+	}
 	blt(lhs[dest], lhs[src], n_lhs[src] * sizeof(token_type));
 	n_lhs[dest] = n_lhs[src];
 	blt(rhs[dest], rhs[src], n_rhs[src] * sizeof(token_type));
@@ -292,7 +297,7 @@ int	src, dest;
 }
 
 /*
- * Return true if equation number "i" is solved for a normal variable.
+ * Return true if equation space "i" is solved for a normal variable.
  */
 int
 solved_equation(i)
@@ -329,12 +334,12 @@ long		v;	/* standard Mathomatic variable */
 }
 
 /*
- * Return true if variable "v" exists in equation number "i".
+ * Return true if variable "v" exists in equation space "i".
  */
 int
 var_in_equation(i, v)
-int	i;
-long	v;
+int	i;	/* index */
+long	v;	/* standard Mathomatic variable */
 {
 	if (n_lhs[i] <= 0)
 		return false;
@@ -428,63 +433,6 @@ char	*cp;
 	return i;
 }
 
-/*
- * Parse an expression with equation space pull if the line starts with "#".
- *
- * Returns the new string position or NULL on error.
- * Currently, there can be no more to parse in the string when this returns.
- */
-char	*
-parse_expr(equation, np, cp)
-token_type	*equation;	/* where the parsed expression is stored (equation side) */
-int		*np;		/* pointer to the returned parsed expression length */
-char		*cp;		/* string to parse */
-{
-	int	i;
-	char	*cp1, *cp2;
-
-	if (!case_sensitive_flag) {
-		str_tolower(cp);
-	}
-	cp1 = skip_space(cp);
-	if (*cp1 == '#') {
-		cp1++;
-		switch (*cp1) {
-		case '+':
-		case '-':
-			i = decstrtol(cp1, &cp2);
-			i = cur_equation + i;
-			break;
-		default:
-			i = decstrtol(cp1, &cp2) - 1;
-			break;
-		}
-		if (cp1 == cp2 || *cp2) {
-			error(_("Error parsing equation space number."));
-			return NULL;
-		}
-		if (i < 0 || i >= n_equations || n_lhs[i] <= 0) {
-			error(_("Equation not defined."));
-			return NULL;
-		}
-		if (n_rhs[i]) {
-			blt(equation, rhs[i], n_rhs[i] * sizeof(token_type));
-			*np = n_rhs[i];
-		} else {
-			blt(equation, lhs[i], n_lhs[i] * sizeof(token_type));
-			*np = n_lhs[i];
-		}
-		list_proc(equation, *np, false);
-		fprintf(gfp, "\n");
-		return cp2;
-	}
-	if ((cp = parse_section(equation, np, cp)) != NULL) {
-		if (extra_characters(cp))
-			return NULL;
-	}
-	return cp;
-}
-
 /*
  * Get an expression from the user.
  * The prompt must be previously copied into the global prompt_str[].
@@ -601,7 +549,7 @@ int	n;		/* maximum size of "string" in bytes */
 	}
 	input_column = strlen(prompt_str);
 #if	READLINE
-	if (readline_enabled) {
+	if (readline_enabled && !echo_input) {
 		cp = readline(prompt_str);
 		if (cp == NULL) {
 			fprintf(gfp, _("\nEnd of input.\n"));
@@ -615,25 +563,29 @@ int	n;		/* maximum size of "string" in bytes */
 			free(cp);
 		}
 	} else {
-		printf("%s", prompt_str);
+		if (!echo_input) {
+			printf("%s", prompt_str);
+		}
 		if (fgets(string, n, stdin) == NULL) {
 			fprintf(gfp, _("\nEnd of input.\n"));
 			exit_program(0);
 		}
 	}
 #else
-	printf("%s", prompt_str);
+	if (!echo_input) {
+		printf("%s", prompt_str);
+	}
 	if (fgets(string, n, stdin) == NULL) {
 		fprintf(gfp, _("\nEnd of input.\n"));
 		exit_program(0);
 	}
 #endif
-	// Fix an fgets() peculiarity:
+	/* Fix an fgets() peculiarity: */
 	i = strlen(string) - 1;
 	if (i >= 0 && string[i] == '\n') {
 		string[i] = '\0';
 	}
-	if (gfp != stdout) {
+	if (gfp != stdout || echo_input) {
 		/* Input that is prompted for is now included in the redirected output of a command to a file,
 		   making redirection like logging. */
 		fprintf(gfp, "%s%s\n", prompt_str, string);
