@@ -70,7 +70,7 @@
 #define	DIVISOR_SIZE		(DEFAULT_N_TOKENS / 2)	/* a nice maximum divisor size */
 
 /*
- * All Mathomatic variables are referenced by the long data type.
+ * All Mathomatic variables are referenced by the value in a C long int variable.
  * The actual name string is stored separately.
  */
 #define	MAX_VAR_NAMES	8000			/* maximum number of variable names, keep this under (VAR_MASK - VAR_OFFSET) */
@@ -86,23 +86,23 @@
 
 typedef	char	sign_array_type[MAX_SUBSCRIPT+2];	/* boolean array for generating unique "sign" variables */
 
-enum kind_list {		/* kinds of tokens specified in the union below */
+enum kind_list {		/* kinds of expression tokens specified in the union below */
 	CONSTANT,
 	VARIABLE,
 	OPERATOR
 };
 
 typedef union {
-	double	constant;	/* internal storage for mathematical constants */
-	long	variable;	/* internal storage for mathematical variables */
+	double	constant;	/* internal storage for Mathomatic numerical constants */
+	long	variable;	/* internal storage for Mathomatic variables */
 /* Predefined special variables follow (order is important): */
 #define	V_NULL		0L	/* null variable, should never be stored in an expression */
-#define	V_E		1L	/* the constant "e" or "e#" */
-#define	V_PI		2L	/* the constant "pi" or "pi#" */
+#define	V_E		1L	/* the symbolic, universal constant "e" or "e#" */
+#define	V_PI		2L	/* the symbolic, universal constant "pi" or "pi#" */
 #define	IMAGINARY	3L	/* the imaginary constant "i" or "i#" */
-#define	SIGN		4L	/* for "sign" variables */
+#define	SIGN		4L	/* for two-valued "sign" variables */
 #define	MATCH_ANY	5L	/* match any variable (wild-card variable) */
-	int	operatr;	/* internal storage for mathematical operators */
+	int	operatr;	/* internal storage for Mathomatic operators */
 /* Valid operators follow (order doesn't matter), 0 is reserved for no operator: */
 #define	PLUS		1	/* a + b */
 #define	MINUS		2	/* a - b */
@@ -111,7 +111,7 @@ typedef union {
 #define	MODULUS		5	/* a % b */
 #define	POWER		6	/* a ^ b */
 #define	FACTORIAL	7	/* a! */
-#define	NEGATE		8	/* special parser operator */
+#define	NEGATE		8	/* special parser operator not seen outside parser */
 #define IDIVIDE		9	/* a // b */
 } storage_type;
 
@@ -121,7 +121,7 @@ typedef	struct {		/* storage structure for each token in an expression */
 	storage_type	token;	/* the actual token */
 } token_type;
 
-typedef struct {		/* variable sort data structure */
+typedef struct {		/* qsort(3) data structure for sorting Mathomatic variables */
 	long	v;		/* Mathomatic variable */
 	int	count;		/* number of times the variable occurs */
 } sort_type;
@@ -134,5 +134,5 @@ typedef struct {		/* variable sort data structure */
 #else
 #define list_tdebug(level)		list_debug(level, tlhs, n_tlhs, trhs, n_trhs)
 #define	side_debug(level, p1, n1)	list_debug(level, p1, n1, NULL, 0)
-#define debug_string(level, str)	{ if (debug_level >= (level)) printf("%s\n", str); }
+#define debug_string(level, str)	{ if (debug_level >= (level)) fprintf(gfp, "%s\n", str); }
 #endif
