@@ -52,16 +52,17 @@ char	*cp;	/* the command line argument */
 int
 version_report()
 {
-	fprintf(gfp, _("Mathomatic version %s\nCompile flags used: "), VERSION);
-#if	__STDC__
-	fprintf(gfp, "__STDC__ ");
-#endif
+	fprintf(gfp, _("Mathomatic version %s\n"), VERSION);
+	fprintf(gfp, _("Compile flags used: "));
 #if	UNIX
 	fprintf(gfp, "UNIX ");
 #endif
 #if	CYGWIN
 	fprintf(gfp, "CYGWIN ");
 #endif
+#if	HANDHELD
+	fprintf(gfp, "HANDHELD ");
+#endif
 #if	READLINE
 	fprintf(gfp, "READLINE ");
 #endif
@@ -81,6 +82,7 @@ version_report()
 	fprintf(gfp, "I18N ");
 #endif
 	fprintf(gfp, _("\nMaximum memory usage: %ld kilobytes\n"), ((long) (N_EQUATIONS + 3L) * n_tokens * sizeof(token_type) * 2L) / 1000L);
+	fprintf(gfp, _("This is GNU LGPL version 2.1 licensed software.\n"));
 	return true;
 }
 
@@ -663,6 +665,8 @@ display_current_directory()
 void
 output_options()
 {
+	fprintf(gfp, "precision = %d digits\n", precision);
+
 	if (!autosolve) {
 		fprintf(gfp, "no ");
 	}
@@ -697,10 +701,15 @@ output_options()
 	}
 	fprintf(gfp, "display2d\n");
 
-	if (!preserve_roots) {
+	if (quiet_mode) {
 		fprintf(gfp, "no ");
 	}
-	fprintf(gfp, "preserve_roots\n");
+	fprintf(gfp, "prompt\n");
+
+	if (!preserve_surds) {
+		fprintf(gfp, "no ");
+	}
+	fprintf(gfp, "preserve_surds\n");
 
 	if (!true_modulus) {
 		fprintf(gfp, "no ");
@@ -810,8 +819,9 @@ char	*cp;
 		if (negate) {
 			screen_columns = 0;
 		} else {
-			if ((i = decstrtol(cp, &cp1)) < 0 || cp == cp1) {
-				error(_("Please specify how wide the screen is in columns."));
+			i = decstrtol(cp, &cp1);
+			if (i < 0 || cp == cp1) {
+				error(_("Please specify how wide the screen is; 0 = infinite columns."));
 				return false;
 			}
 			cp = cp1;
@@ -819,6 +829,16 @@ char	*cp;
 		}
 		goto check_return;
 	}
+	if (strncasecmp(cp, "precision", 4) == 0) {
+		cp = skip_param(cp);
+		i = decstrtol(cp, &cp1);
+		if (i < 0 || i > 14 || cp == cp1) {
+			error(_("Please specify a display precision between 0 and 14 digits."));
+			return false;
+		}
+		precision = i;
+		return true;
+	}
 	if (strncasecmp(cp, "autosolve", 9) == 0) {
 		cp = skip_param(cp);
 		autosolve = !negate;
@@ -839,9 +859,14 @@ char	*cp;
 		display2d = !negate;
 		goto check_return;
 	}
+	if (strncasecmp(cp, "prompt", 6) == 0) {
+		cp = skip_param(cp);
+		quiet_mode = negate;
+		goto check_return;
+	}
 	if (strncasecmp(cp, "preserve", 8) == 0) {
 		cp = skip_param(cp);
-		preserve_roots = !negate;
+		preserve_surds = !negate;
 		goto check_return;
 	}
 	if (strncasecmp(cp, "true_modulus", 10) == 0) {
@@ -944,7 +969,7 @@ char	*cp;
 	char	*cp1;
 	char	buf[MAX_CMD_LEN];
 
-	if (test_mode || !isatty(0)) {
+	if (test_mode /* || !isatty(0) */) {
 		return true;
 	}
 	if (*cp == '\0') {
@@ -1243,10 +1268,14 @@ char	*cp;
 				return false;
 		}
 		iterations = decstrtol(cp, &cp);
-		if (*cp || iterations <= 0) {
+		if (*cp || iterations < 0) {
 			error(_("Positive integer required."));
 			return false;
 		}
+		if (iterations == 0) {
+			warning(_("Infinite iterations."));
+			iterations = LONG_MAX - 1L;
+		}
 	}
 calc_again:
 	value_entered = false;
@@ -1477,7 +1506,12 @@ char	*cp;
 {
 	int		i, j;
 	int		diff_sign;
+	int		symb = false;
 
+	if (strncasecmp(cp, "symbolic", 3) == 0) {
+		symb = true;
+		cp = skip_param(cp);
+	}
 	if (strcmp_tospace(cp, "with") == 0) {
 		cp = skip_param(cp);
 	}
@@ -1505,8 +1539,10 @@ char	*cp;
 				return true;
 			}
 			debug_string(0, _("Simplifying both expressions..."));
-			simpa_side(lhs[i], &n_lhs[i], true, false);
-			simpa_side(lhs[j], &n_lhs[j], true, false);
+			symb_flag = symb;
+			simpa_side(lhs[i], &n_lhs[i], false, false);
+			simpa_side(lhs[j], &n_lhs[j], false, false);
+			symb_flag = false;
 #if	!SILENT
 			if (debug_level >= 0) {
 				list_sub(i);
@@ -1540,8 +1576,10 @@ char	*cp;
 			goto times_neg1;
 		}
 		debug_string(0, _("Simplifying both equations..."));
-		simpa_side(rhs[i], &n_rhs[i], true, false);
-		simpa_side(rhs[j], &n_rhs[j], true, false);
+		symb_flag = symb;
+		simpa_side(rhs[i], &n_rhs[i], false, false);
+		simpa_side(rhs[j], &n_rhs[j], false, false);
+		symb_flag = false;
 #if	!SILENT
 		if (debug_level >= 0) {
 			list_sub(i);
@@ -1569,8 +1607,10 @@ char	*cp;
 		return true;
 	}
 	debug_string(0, _("Simplifying both equations..."));
-	simpa_side(rhs[i], &n_rhs[i], true, false);
-	simpa_side(rhs[j], &n_rhs[j], true, false);
+	symb_flag = symb;
+	simpa_side(rhs[i], &n_rhs[i], false, false);
+	simpa_side(rhs[j], &n_rhs[j], false, false);
+	symb_flag = false;
 	if (compare_rhs(i, j, &diff_sign)) {
 		fprintf(gfp, _("Equations are identical.\n"));
 		return true;
@@ -1843,10 +1883,14 @@ next_var:
 	goto next_var;
 }
 
+/*
+ * Solve equation number i for v and substitute the RHS
+ * into all occurrences of v in the current equation, simplifying a little.
+ */
 static int
 elim_sub(i, v)
 int	i;	/* equation number */
-long	v;	/* variable */
+long	v;	/* Mathomatic variable */
 {
 	token_type	want;
 
@@ -1864,7 +1908,7 @@ long	v;	/* variable */
 	want.kind = VARIABLE;
 	want.token.variable = v;
 	if (solve_sub(&want, 1, lhs[i], &n_lhs[i], rhs[i], &n_rhs[i]) <= 0) {
-		debug_string(0, _("Solve failed."));
+		error(_("Solve failed."));
 		return false;
 	}
 	subst_var_with_exp(rhs[cur_equation], &n_rhs[cur_equation], rhs[i], n_rhs[i], v);
@@ -1883,31 +1927,39 @@ display_cmd(cp)
 char	*cp;
 {
 	int	i, j;
+	char	*cp1;
 	int	factor_flag;
 
 	factor_flag = (strcmp_tospace(cp, "factor") == 0);
 	if (factor_flag) {
 		cp = skip_param(cp);
 	}
-	if (!get_range_eol(&cp, &i, &j)) {
-		return false;
-	}
-	for (; i <= j; i++) {
-		if (n_lhs[i] > 0) {
-			make_fractions_and_group(i);
-			if (factor_flag || factor_int_flag) {
-				factor_int_sub(i);
-			}
-#if	LIBRARY
-			if (gfp == stdout) {
-				free(result_str);
-				result_str = list_equation(i, false);
-				return(result_str != NULL);
-			}
-#endif
-			flist_equation(i);
+	do {
+		cp1 = cp;
+		if (!get_range(&cp, &i, &j)) {
+			return false;
 		}
-	}
+		if (*cp && cp == cp1) {
+			error(_("Invalid argument."));
+			return false;
+		}
+		for (; i <= j; i++) {
+			if (n_lhs[i] > 0) {
+				make_fractions_and_group(i);
+				if (factor_flag || factor_int_flag) {
+					factor_int_sub(i);
+				}
+#if     LIBRARY
+	                        if (gfp == stdout) {
+	                                free(result_str);
+	                                result_str = list_equation(i, false);
+	                                return(result_str != NULL);
+	                        }
+#endif
+				flist_equation(i);
+			}
+		}
+	} while (*cp);
 	return true;
 }
 
@@ -2288,7 +2340,7 @@ char	*cp;
 			sign_flag = true;
 			continue;
 		}
-		if (strncasecmp(cp, "symbolic", 4) == 0) {
+		if (strncasecmp(cp, "symbolic", 3) == 0) {
 			symb = true;
 			continue;
 		}
@@ -2597,8 +2649,8 @@ char	*cp;
 	}
 	for (; i <= j; i++) {
 		if (n_lhs[i]) {
-			frac_side(lhs[i], &n_lhs[i]);
-			frac_side(rhs[i], &n_rhs[i]);
+			simple_frac_side(lhs[i], &n_lhs[i]);
+			simple_frac_side(rhs[i], &n_rhs[i]);
 			if (!return_result(i))
 				return false;
 		}
@@ -2639,7 +2691,7 @@ char	*cp;
 	char	buf[MAX_CMD_LEN];
 
 	if (*cp == '\0') {
-		error(_("No file specified."));
+		error(_("No read file specified."));
 		return false;
 	}
 	fp = NULL;
@@ -2649,6 +2701,7 @@ char	*cp;
 		fp = fopen(cp, "r");
 		if (fp == NULL) {
 			error(_("Can't open input file."));
+			printf(_("Read of file \"%s\" failed.\n"), cp);
 			return false;
 		}
 	} else {
@@ -2749,7 +2802,7 @@ char	*cp;
 		unlink(tmp_file);
 		return rv;
 	} else {
-		if (access(cp, 6)) {
+		if (access(cp, R_OK | W_OK)) {
 			error(_("You can only edit existing/writable files or all equations."));
 			return false;
 		}
@@ -2803,12 +2856,16 @@ char	*cp;
 
 	clean_up();	/* end any redirection */
 	if (*cp == '\0') {
-		error(_("No file specified."));
+		error(_("No save file specified."));
 		return false;
 	}
 #if	!SILENT
-	if (access(cp, 0) == 0) {
-		snprintf(prompt_str, sizeof(prompt_str), _("\"%s\" exists, overwrite (y/n)? "), cp);
+	if (access(cp, F_OK) == 0) {
+		if (access(cp, W_OK)) {
+			error(_("Specified save file is not writable."));
+			return false;
+		}
+		snprintf(prompt_str, sizeof(prompt_str), _("File \"%s\" exists, overwrite (y/n)? "), cp);
 		if (!get_yes_no()) {
 			printf(_("Command aborted.\n"));
 			return false;
@@ -2817,7 +2874,7 @@ char	*cp;
 #endif
 	fp = fopen(cp, "w");
 	if (fp == NULL) {
-		error(_("Can't create specified file."));
+		error(_("Can't create specified save file."));
 		return false;
 	}
 	gfp = fp;
@@ -2829,7 +2886,7 @@ char	*cp;
 		rv = false;
 	if (rv) {
 #if	!SILENT
-		printf(_("All equations saved in file: \"%s\".\n"), cp);
+		printf(_("All equations saved in file \"%s\".\n"), cp);
 #endif
 	} else {
 		error(_("Error encountered while saving equations."));
