@@ -575,7 +575,7 @@ char	*cp;
 				return false;
 			}
 		} else {
-			printf(_("Derivatives will be taken until they reach zero...\n"));
+			warning(_("Derivatives will be taken until they reach zero..."));
 			order = LONG_MAX - 1L;
 		}
 	}
