@@ -34,19 +34,18 @@ extern int		case_sensitive_flag;
 extern int		factor_int_flag;
 extern int		display2d;
 extern int		approximate_roots;
-extern int		preserve_roots;
+extern int		preserve_surds;
 extern int		true_modulus;
 extern volatile int	screen_columns;
 extern volatile int	screen_rows;
 extern int		finance_option;
 extern int		autosolve;
 extern int		autocalc;
-extern char		special_variable_characters[200];
+extern char		special_variable_characters[256];
 extern int		integer_coefficients;
 extern int		right_associative_power;
 extern int		negate_high_precedence;
 extern int		power_starstar;
-extern int		display_hexadecimal;
 extern int		debug_level;
 extern int		domain_check;
 extern int		color_flag;
@@ -76,6 +75,7 @@ extern FILE		*gfp;
 extern jmp_buf		jmp_save;
 extern int		test_mode;
 extern int		quiet_mode;
+extern int		echo_input;
 extern volatile int	abort_flag;
 
 extern const char	*error_str;
