@@ -777,6 +777,16 @@ int		*np, loc, i1, n1, i2, n2, level;
 	if (se_compare(&equation[i1], i - i1, &equation[i2], j - i2, &diff_sign)) {
 		goto common_base;
 	}
+	if (i < e1 && j < e2) {
+		if (se_compare(&equation[i1], n1, &equation[i2], j - i2, &diff_sign)) {
+			i = e1;
+			goto common_base;
+		}
+		if (se_compare(&equation[i1], i - i1, &equation[i2], n2, &diff_sign)) {
+			j = e2;
+			goto common_base;
+		}
+	}
 	return false;
 
 common_base:
@@ -930,7 +940,7 @@ int		*np, loc, i1, n1, i2, n2, level;
 {
 	int		e1, e2;
 	int		op1, op2;
-	int		pop1;
+	int		pop1 = TIMES;
 	int		start2;
 	int		i, j, k;
 	int		b1, b2;
@@ -961,6 +971,17 @@ int		*np, loc, i1, n1, i2, n2, level;
 		}
 	}
 	start2 = j;
+	if (se_compare(&equation[i+1], e1 - (i + 1), &one_token, 1, &diff_sign)) {
+		return false;
+	}
+	if (se_compare(&equation[i+1], e1 - (i + 1), &equation[j+1], e2 - (j + 1), &diff_sign)) {
+		b1 = i + 1;
+		b2 = j + 1;
+		i = e1;
+		j = e2;
+		goto common_exponent;
+	}
+
 fp_outer:
 	pop1 = equation[i].token.operatr;
 	if (pop1 == POWER)
@@ -968,9 +989,6 @@ fp_outer:
 	b1 = i + 1;
 	if (b1 >= e1)
 		return false;
-#if	false
-	i = e1;
-#else
 	i = b1 + 1;
 	for (; i < e1; i += 2) {
 		if (equation[i].level == (level + 1)
@@ -979,7 +997,6 @@ fp_outer:
 			break;
 		}
 	}
-#endif
 	if (se_compare(&equation[b1], i - b1, &one_token, 1, &diff_sign)) {
 		goto fp_outer;
 	}
@@ -988,9 +1005,6 @@ fp_inner:
 	b2 = j + 1;
 	if (b2 >= e2)
 		goto fp_outer;
-#if	false
-	j = e2;
-#else
 	j = b2 + 1;
 	for (; j < e2; j += 2) {
 		if (equation[j].level == (level + 1)
@@ -999,7 +1013,6 @@ fp_inner:
 			break;
 		}
 	}
-#endif
 	if (equation[b2-1].token.operatr == POWER) {
 		if (pop1 != TIMES)
 			goto fp_inner;
@@ -1007,6 +1020,7 @@ fp_inner:
 		goto fp_inner;
 	}
 	if (se_compare(&equation[b1], i - b1, &equation[b2], j - b2, &diff_sign)) {
+common_exponent:
 		if (op2 == DIVIDE)
 			diff_sign = !diff_sign;
 		all_divide = (op1 == DIVIDE && diff_sign);
