@@ -21,10 +21,7 @@ gcd(d1, d2)
 double	d1, d2;
 {
 	int	count;
-	double	larger;
-	double	divisor;
-	double	r1;
-	double	d;
+	double	larger, divisor, remainder1, lower_limit;
 
 	if (!isfinite(d1) || !isfinite(d2)) {
 		return 0.0;	/* operands must be finite */
@@ -38,22 +35,19 @@ double	d1, d2;
 		larger = d2;
 		divisor = d1;
 	}
-	if (divisor <= 0.0 || larger >= MAX_K_INTEGER) {
-		return 0.0;	/* out of range */
-	}
-	d = larger * epsilon;
-	if (d >= divisor) {
-		return 0.0;	/* result would be too inaccurate */
+	lower_limit = larger * epsilon;
+	if (divisor <= lower_limit || larger >= MAX_K_INTEGER) {
+		return 0.0;	/* out of range, result would be too inaccurate */
 	}
 	for (count = 1; count < 50; count++) {
-		r1 = fmod(larger, divisor);
-		if (r1 <= d || (divisor - r1) <= d) {
-			if (r1 != 0.0 && divisor <= (100 * d))
+		remainder1 = fabs(fmod(larger, divisor));
+		if (remainder1 <= lower_limit || fabs(divisor - remainder1) <= lower_limit) {
+			if (remainder1 != 0.0 && divisor <= (100.0 * lower_limit))
 				return 0.0;
 			return divisor;
 		}
 		larger = divisor;
-		divisor = r1;
+		divisor = remainder1;
 	}
 	return 0.0;
 }
@@ -71,9 +65,7 @@ double	d1, d2;
 
 	divisor = gcd(d1, d2);
 	if (divisor != 0.0) {
-		if (fmod(d1, divisor) != 0.0)
-			return 0.0;
-		if (fmod(d2, divisor) != 0.0)
+		if (gcd(d1 / divisor, d2 / divisor) != 1.0)
 			return 0.0;
 	}
 	return divisor;
@@ -102,10 +94,10 @@ double	d1;	/* value to round */
  * numerator = d / divisor
  * denominator = 1.0 / divisor
  *
- * Return true with integer numerator and denominator if conversion was successful.
+ * Return true with integers in numerator and denominator if conversion was successful.
  * Otherwise return false with numerator = "d" and denominator = "1.0".
  *
- * True return indicates "d" is rational and finite, otherwise "d" is irrational.
+ * True return indicates "d" is rational and finite, otherwise "d" is probably irrational.
  */
 int
 f_to_fraction(d, numeratorp, denominatorp)
@@ -126,7 +118,7 @@ double	*denominatorp;	/* returned denominator */
 	if (fmod(d, 1.0) == 0.0) {
 		return true;
 	}
-	k3 = fabs(d) * epsilon;
+	k3 = fabs(d) * small_epsilon;
 	k4 = my_round(d);
 	if (k4 != 0.0 && fabs(k4 - d) <= k3) {
 		*numeratorp = k4;
@@ -152,12 +144,7 @@ double	*denominatorp;	/* returned denominator */
 		if (fabs(k3 - k4) > (small_epsilon * fabs(k3))) {
 			return false;	/* result is too inaccurate */
 		}
-		if (fmod(numerator, 1.0)) {
-			error("Internal error: Numerator is not integral.");
-		}
-		if (fmod(denominator, 1.0)) {
-			error("Internal error: Denominator is not integral.");
-		}
+/* numerator and denominator are integral */
 		*numeratorp = numerator;
 		*denominatorp = denominator;
 		return true;
