@@ -39,19 +39,18 @@ int		precision = 14;				/* the display precision for doubles (number of digits)
 int		case_sensitive_flag = true;		/* "set case_sensitive" flag */
 int		factor_int_flag;			/* factor integers when displaying expressions */
 int		display2d = true;			/* "set display2d" flag */
-int		preserve_roots = true;			/* set option to preserve roots like (2^.5) */
+int		preserve_surds = true;			/* set option to preserve roots like (2^.5) */
 int		true_modulus = true;				/* true for mathematically correct modulus */
 volatile int	screen_columns = STANDARD_SCREEN_COLUMNS;	/* screen width of the terminal; 0 = infinite */
 volatile int	screen_rows = STANDARD_SCREEN_ROWS;		/* screen height of the terminal; 0 = infinite */
 int		finance_option;				/* for displaying dollars and cents */
 int		autosolve = true;			/* Allows solving by typing the variable name at the prompt */
 int		autocalc = true;			/* Allows automatically calculating a numerical expression */
-char		special_variable_characters[200] = {'\\', '\0'};	/* user defined characters for variable names */
+char		special_variable_characters[256] = "\\"; /* user defined characters for variable names, 0 terminated */
 int		integer_coefficients = false;		/* if true, factor out the GCD of integer coefficients */
 int		right_associative_power;		/* if true, evaluate power operators right to left */
 int		negate_high_precedence = true;		/* if true, negation (-x) has the highest precedence */
 int		power_starstar;				/* if true, display power operator as "**", otherwise "^" */
-int		display_hexadecimal = false;		/* if true, output constants in hexadecimal */
 #if	!SILENT
 int		debug_level;				/* current debug level */
 #endif
@@ -85,10 +84,11 @@ int		uno;			/* number of unique factors stored in unique[] */
 
 /* misc. variables */
 sign_array_type	sign_array;		/* for keeping track of unique "sign" variables */
-FILE		*gfp;			/* global output file pointer */
+FILE		*gfp;			/* global output file pointer, for dynamically redirecting Mathomatic output */
 jmp_buf		jmp_save;		/* for setjmp(3) to longjmp(3) to when an error happens deep within this code */
 int		test_mode;		/* test mode flag (-t) */
 int		quiet_mode;		/* quiet mode (-q, don't display prompts) */
+int		echo_input;		/* if true, echo input and don't use readline */
 int		readline_enabled = true;	/* set to false (-r) to disable readline */
 int		partial_flag;		/* normally true for partial unfactoring, false for "unfactor fully" */
 int		symb_flag;		/* true during "simplify symbolic" */
