@@ -18,6 +18,7 @@ typedef	struct {
 					/* function is passed a char pointer and returns true if successful */
 	char	*usage;			/* command syntax text */
 	char	*info;			/* one line description of command */
+	char	*extra;			/* one line extra info on command */
 } com_type;
 
 /*
@@ -29,14 +30,14 @@ static com_type com_list[] = {
 #if	!LIBRARY
 {	"calculate",	NULL,			calculate_cmd,		"[\"repeat\"] [\"factor\"] [variable iterations]",	"Temporarily plug in values for variables and approximate." },
 #endif
-{	"clear",	NULL,			clear_cmd,		"[equation-number-ranges]",				"Delete expressions stored in memory so equation spaces can be reused." },
+{	"clear",	NULL,			clear_cmd,		"[equation-number-ranges]",				"Delete expressions stored in memory so equation spaces can be reused.", "Tip: Use \"clear all\" to restart Mathomatic." },
 #if	!LIBRARY
-{	"code",		NULL,			code_cmd,		"[\"c\" or \"java\" or \"python\" or \"integer\"] [equation-number-ranges]",	"Output C, Java, or Python code for the specified equations." },
+{	"code",		NULL,			code_cmd,		"[\"c\" or \"java\" or \"python\" or \"integer\"] [equation-number-ranges]",	"Output C, Java, or Python code for the specified equations.", "Related commands: simplify, optimize, and variables." },
 #endif
-{	"compare",	NULL,			compare_cmd,		"equation-number [\"with\" equation-number]",		"Compare two equation spaces to see if they are the same." },
+{	"compare",	NULL,			compare_cmd,		"[\"symbolic\"] equation-number [\"with\" equation-number]",	"Compare two equation spaces to see if they are the same." },
 {	"copy",		NULL,			copy_cmd,		"[equation-number-range]",				"Duplicate the specified equation spaces." },
 {	"derivative",	"differentiate",	derivative_cmd,		"[\"nosimplify\"] [variable or \"all\"] [order]",	"Symbolically differentiate and simplify, order times." },
-{	"display",	NULL,			display_cmd,		"[\"factor\"] [equation-number-range]",			"Display equation spaces in multi-line fraction format." },
+{	"display",	NULL,			display_cmd,		"[\"factor\"] [equation-number-ranges]",			"Display equation spaces in pretty multi-line (2D) fraction format." },
 #if	!LIBRARY
 {	"divide",	NULL,			divide_cmd,		"[variable]",						"Prompt for 2 numbers or polynomials and divide. Give result and GCD." },
 #endif
@@ -46,22 +47,22 @@ static com_type com_list[] = {
 #endif
 {	"eliminate",	NULL,			eliminate_cmd,		"[\"repeat\"] variables or \"all\" [\"using\" equation-number]",	"Substitute the specified variables with solved equations." },
 {	"extrema",	NULL,			extrema_cmd,		"[variable] [order]",					"Find possible local minimums and maximums of the current expression." },
-{	"factor",	NULL,			factor_cmd,		"[\"number\" [integers]] or [equation-number-range] [variables]",	"Factor given integers or factor variables in expressions." },
-{	"fraction",	NULL,			fraction_cmd,		"[equation-number-range]",				"Convert expressions with algebraic fractions into a single fraction." },
-{	"help",		NULL,			help_cmd,		"[topic or command-names]",				"Short, built-in help." },
-{	"imaginary",	NULL,			imaginary_cmd,		"[variable]",						"Copy the imaginary part of the current expression." },
-{	"integrate",	"integral",		integrate_cmd,		"[\"constant\" or \"definite\"] variable [order]",	"Symbolically integrate polynomials and simplify, order times." },
+{	"factor",	NULL,			factor_cmd,		"[\"numbers\" [integers]] or [equation-number-range] [variables]",	"Factor given integers or factor variables in equation spaces." },
+{	"fraction",	NULL,			fraction_cmd,		"[equation-number-range]",				"Convert expressions with algebraic fractions into a single simple fraction." },
+{	"help",		NULL,			help_cmd,		"[topic or command-names]",				"Short, built-in help and reference." },
+{	"imaginary",	NULL,			imaginary_cmd,		"[variable]",						"Copy the imaginary part of the current expression.", "Related command: real." },
+{	"integrate",	"integral",		integrate_cmd,		"[\"constant\" or \"definite\"] variable [order]",	"Symbolically integrate polynomials order times, then simplify." },
 {	"laplace",	NULL,			laplace_cmd,		"[\"inverse\"] variable",				"Compute the Laplace or inverse Laplace transform of polynomials." },
 {	"limit",	NULL,			limit_cmd,		"variable expression",					"Take the limit as variable goes to expression (experimental)." },
 {	"list",		NULL,			list_cmd,		"[\"export\" or \"maxima\"] [equation-number-ranges]",	"Display equation spaces in single-line format." },
 #if	!LIBRARY
-{	"nintegrate",	NULL,			nintegrate_cmd,		"[\"trapezoid\"] variable [partitions]",		"Approximate the definite integral using Simpson's rule."},
-{	"optimize",	NULL,			optimize_cmd,		"[equation-number-range]",				"Split up an equation into smaller, more efficient equations." },
+{	"nintegrate",	NULL,			nintegrate_cmd,		"[\"trapezoid\"] variable [partitions]",		"Do numerical definite integration using Simpson's rule."},
+{	"optimize",	NULL,			optimize_cmd,		"[equation-number-range]",				"Split up equations into smaller, more efficient equations.", "Related command: code." },
 #endif
 #if	!LIBRARY
 {	"pause",	NULL,			pause_cmd,		"[text]",						"Wait for user to press the Enter key. Optionally display a message." },
 #endif
-{	"product",	NULL,			product_cmd,		"variable start end [step-size]",			"Compute the product as variable goes from start to end." },
+{	"product",	NULL,			product_cmd,		"variable start end [step-size]",			"Compute the product as variable goes from start to end.", "Related command: sum." },
 #if	READLINE
 {	"push",		NULL,			push_cmd,		"[equation-number-range]",				"Push the specified expressions into the readline history." },
 #endif
@@ -71,25 +72,25 @@ static com_type com_list[] = {
 #if	!SECURE
 {	"read",		NULL,			read_cmd,		"file-name",						"Read in a text file as if it was typed in." },
 #endif
-{	"real",		NULL,			real_cmd,		"[variable]",						"Copy the real part of the current expression." },
+{	"real",		NULL,			real_cmd,		"[variable]",						"Copy the real part of the current expression.", "Related command: imaginary." },
 {	"replace",	NULL,			replace_cmd,		"[variables [\"with\" expression]]",			"Substitute variables in the current equation with expressions." },
 #if	!LIBRARY
 {	"roots",	NULL,			roots_cmd,		"root real-part imaginary-part",			"Display all the roots of a complex number." },
 #endif
 #if	!SECURE
-{	"save",		NULL,			save_cmd,		"file-name",						"Save all equation spaces in a text file." },
+{	"save",		NULL,			save_cmd,		"file-name",						"Save all equation spaces in a text file.", "Related command: read." },
 #endif
 {	"set",		NULL,			set_cmd,		"[[\"no\"] option]",					"Set or display various session options." },
 {	"simplify",	NULL,			simplify_cmd,		"[\"sign\"] [\"symbolic\"] [\"quick\"] [\"fraction\"] [equation-number-range]",	"Completely simplify expressions." },
 {	"solve",	NULL,			solve_cmd,		"[\"verify\"] variable or \"0\"",			"Solve the current equation for a variable or for zero." },
-{	"sum",		NULL,			sum_cmd,		"variable start end [step-size]",			"Compute the summation as variable goes from start to end." },
+{	"sum",		NULL,			sum_cmd,		"variable start end [step-size]",			"Compute the summation as variable goes from start to end.", "Related command: product." },
 #if	!LIBRARY
-{	"tally",	NULL,			tally_cmd,		"[\"average\"]",					"Prompt for and add entries, show running (grand) total." },
+{	"tally",	NULL,			tally_cmd,		"[\"average\"]",					"Prompt for and add entries, show total and optionally the average." },
 #endif
 {	"taylor",	NULL,			taylor_cmd,		"variable order point",					"Compute the Taylor series expansion of the current expression." },
-{	"unfactor",	"expand",		unfactor_cmd,		"[\"fully\"] [\"quick\"] [equation-number-range]",	"Algebraically expand (multiply out) expressions." },
+{	"unfactor",	"expand",		unfactor_cmd,		"[\"fully\"] [\"quick\"] [\"power\"] [equation-number-range]",	"Algebraically expand (multiply out) expressions." },
 #if	!LIBRARY
-{	"variables",	NULL,			variables_cmd,		"[\"c\" or \"java\" or \"integer\"] [equation-number-range]",	"Output all variable names within the specified equations." },
+{	"variables",	NULL,			variables_cmd,		"[\"c\" or \"java\" or \"integer\"] [equation-number-range]",	"Output all variable names within the specified equations.", "Related command: code." },
 #endif
 {	"version",	NULL,			version_cmd,		"",							"Display version number, compile flags, and memory usage." }
 };
@@ -234,10 +235,11 @@ char	*cp;
 	FILE	*fp;
 	int	append_flag;
 
+	init_gvars();		/* make sure we are in the default state */
+	set_sign_array();	/* register all sign variables so that the next ones will be unique */
 	if (cp == NULL) {
 		return false;
 	}
-	set_sign_array();
 	cp_start = cp;
 	cp = skip_space(cp);
 /* handle the equation number selector */
@@ -424,6 +426,10 @@ int	i;	/* command table index of command */
 		fprintf(gfp, "Alternate name for this command: %s\n", com_list[i].secondary_name);
 		rows++;
 	}
+	if (com_list[i].extra) {
+		fprintf(gfp, "%s\n", com_list[i].extra);
+		rows++;
+	}
 	fprintf(gfp, "\n");
 	return rows;
 }
@@ -475,12 +481,13 @@ next_argument:
 			P("or on the Ubuntu Launchpad website:");
 			P("\thttp://bugs.launchpad.net/mathomatic\n");
 
-			P("Please include the version number.");
+			P("Please include the version number:");
+			version_report();
 			return true;
 		}
 		if (strncasecmp(cp, "usage", cp1 - cp) == 0) {
-			P("Command Usage Syntax");
-			P("--------------------");
+			P("Mathomatic Command Usage Syntax");
+			P("-------------------------------");
 			for (i = 0, row = 3; i < ARR_CNT(com_list); i++) {
 				fprintf(gfp, "%s %s\n", com_list[i].name, com_list[i].usage);
 				row++;
@@ -492,32 +499,6 @@ next_argument:
 			}
 			return true;
 		}
-		if (strncasecmp(cp, "geometry", cp1 - cp) == 0) {
-			P("Commonly used standard (Euclidean) geometric formulas");
-			P("-----------------------------------------------------");
-			P("Triangle of base \"b\" and height \"h\":");
-			P("    area = b*h/2\n");
-
-			P("Rectangle of length \"l\" and width \"w\":");
-			P("    area = l*w                    perimeter = 2*l + 2*w\n");
-
-			P("Trapezoid of parallel sides \"a\" and \"b\", and \"d\" distance between them:");
-			P("    area = d*(a + b)/2\n");
-
-			P("Circle of radius \"r\":");
-			P("    area = pi*r^2                 perimeter = 2*pi*r");
-			P("    area = perimeter*r/2\n");
-
-			P("Rectangular solid of length \"l\", width \"w\", and height \"h\":");
-			P("    volume = l*w*h                surface_area = 2*l*w + 2*l*h + 2*w*h\n");
-
-			P("Sphere of radius \"r\":");
-			P("    volume = 4/3*pi*r^3           surface_area = 4*pi*r^2\n");
-
-			P("Convex polygon of \"n\" sides, sum of all interior angles formula:");
-			P("    sum = (n - 2)*180 degrees     sum = (n - 2)*pi radians");
-			return true;
-		}
 		if (strncasecmp(cp, "expressions", cp1 - cp) == 0 || strncasecmp(cp, "equations", cp1 - cp) == 0) {
 			P("To enter an expression or equation, simply type it in at the prompt.");
 			P("Operators have precedence decreasing as indicated:\n");
@@ -539,7 +520,7 @@ next_argument:
 			P("    sign, sign1, sign2, sign3, ... - variables that can only be +1 or -1");
 			P("    inf - floating point infinity constant (not a variable)\n");
 
-			P("Absolute value notation \"|x|\" and dual polarity \"+/-\" are understood.");
+			P("Absolute value notation \"|x|\" and dual polarity \"+/-x\" are understood.");
 			return true;
 		}
 		if (is_all(cp)) {
@@ -551,7 +532,6 @@ next_argument:
 					row = 1;
 					if (!pause_cmd(""))
 						return false;
-					printf("\n");
 				}
 			}
 			P("Full documentation can be found at \"http://mathomatic.org/math/doc/\".");
@@ -566,7 +546,6 @@ next_argument:
 	P("Type \"help equations\" for help with entering expressions and equations.");
 	P("Type \"help all\" for a summary and syntax of all commands.");
 	P("Type \"help usage\" to display the syntax of all commands.");
-	P("Type \"help geometry\" for some commonly used geometric formulas.");
 	P("\"help\" or \"?\" followed by command names will give info on those commands.\n");
 
 	fprintf(gfp, "These are the %d commands:\n", ARR_CNT(com_list));
