@@ -841,7 +841,7 @@ char	*cp;
 	approximate_roots = false;
 
 #if	!SILENT
-	printf(_("Integration successful.\n"));
+	printf(_("Numerical integration successful.\n"));
 #endif
 	if (n_rhs[cur_equation]) {
 		blt(lhs[i], lhs[cur_equation], n_lhs[cur_equation] * sizeof(token_type));
