@@ -15,7 +15,7 @@
 static int	flist();
 static int	flist_recurse();
 
-/* ANSI color code array for 8 color ANSI, we don't use black */
+/* ANSI terminal color code array for 8 color ANSI, we don't use black */
 static int	carray[] = {
 	32,	/* green (default color) */
 	33,	/* yellow */
@@ -48,9 +48,9 @@ static char	*html_carray[] = {
 	"navy"
 };
 
-/* global variables for flist() */
-int	cur_line;	/* current line */
-int	cur_pos;	/* current position in the current line on the screen */
+/* global variables for flist() below */
+static int	cur_line;	/* current line */
+static int	cur_pos;	/* current position in the current line on the screen */
 
 /*
  * Reset terminal attributes function.
@@ -315,7 +315,7 @@ int	lang_code;	/* language code */
 
 /*
  * Display an expression in single-line format.
- * Use color if available.
+ * Use color if color mode is set.
  * The expression is not modified.
  *
  * Return number of characters output (excluding escape sequences).
@@ -366,11 +366,7 @@ int		export_flag;	/* flag for exportable format (usually false) */
 					len += fprintf(gfp, "%.*f", finance_option, p1[i].token.constant);
 				}
 			} else {
-				if (display_hexadecimal) {
-					len += fprintf(gfp, "%a", p1[i].token.constant);
-				} else {
-					len += fprintf(gfp, "%.*g", precision, p1[i].token.constant);
-				}
+				len += fprintf(gfp, "%.*g", precision, p1[i].token.constant);
 			}
 			break;
 		case VARIABLE:
@@ -780,8 +776,8 @@ int		int_flag;	/* integer arithmetic flag, should work with any language */
 }
 
 /*
- * Display an equation space in multi-line fraction format.
- * Use color if available.
+ * Display an equation space in 2D multi-line fraction format.
+ * Use color if color mode is set.
  *
  * Return the total width of the output (that is, the required number of screen columns)
  * or zero on failure.
@@ -854,6 +850,7 @@ make_smaller:
 		fprintf(gfp, "\n");
 	}
 	if (sind < n_rhs[n]) {
+/* output second half of split equation that was too wide to display on the screen without splitting */
 		fprintf(gfp, "\n");
 		for (cur_line = max2_line; cur_line >= min2_line; cur_line--) {
 			cur_pos = 0;
@@ -866,7 +863,9 @@ make_smaller:
 }
 
 /*
- * Display a line of an expression if "out_flag" is true.
+ * Display a line of an expression in 2D fraction format if "out_flag" is true.
+ * The number of the line to output is stored in the global variable cur_line.
+ * 0 is the middle line, lines above are positive, lines below are negative.
  * Use color if available.
  *
  * Return the width of the expression (that is, the required number of screen columns).
@@ -1032,11 +1031,7 @@ check_again:
 					len += snprintf(buf, sizeof(buf), "%.*f", finance_option, p1[i].token.constant);
 				}
 			} else {
-				if (display_hexadecimal) {
-					len += snprintf(buf, sizeof(buf), "%a", p1[i].token.constant);
-				} else {
-					len += snprintf(buf, sizeof(buf), "%.*g", precision, p1[i].token.constant);
-				}
+				len += snprintf(buf, sizeof(buf), "%.*g", precision, p1[i].token.constant);
 			}
 			if (oflag)
 				fprintf(gfp, "%s", buf);
