@@ -4,8 +4,8 @@
  *
  * Copyright (C) 1987-2008 George Gesslein II.
  *
- * Output to stderr is only done in this file.  The rest of the code
- * should not output to stderr.
+ * Output to stderr is only done in this file.  The rest of the Mathomatic code
+ * should not output to stderr; error messages should use error() or go to stdout.
  *
  * This program only supports binary and unary operators.
  * Unary operators are implemented as a binary operation with a dummy operand.
@@ -21,13 +21,15 @@
  * contains the current length of the expression stored in the array.
  * This length is always odd and must never exceed "n_tokens".
  *
- * Only one POWER operator is allowed per level in the storage format,
- * and no other operators may be on that level.  Same with the FACTORIAL
- * and MODULUS operators.
+ * In the storage format,
+ * any number of TIMES and DIVIDE operators may be on the same level of parentheses,
+ * because they are similar and the most basic multiplicative class operators.
+ * The same for the PLUS and MINUS operators, because they are similar (additive class).
+ * All other operators are only allowed one single operator per level of parentheses,
+ * and no same nor different operators may be with it on that level within the current grouping.
  *
- * Any number of TIMES and DIVIDE operators may be on the same
- * level, because they are simple multiplicative class operators.
- * The same for PLUS and MINUS, because they are additive class operators.
+ * Most of the expression manipulation and comparison routines are recursive,
+ * calling themselves for each level of parentheses.
  *
  * See the file "am.h" to start understanding the Mathomatic code and
  * to adjust memory usage.
@@ -139,7 +141,7 @@ char	**argv;
 #if	SECURE
 		printf(_("Secure "));
 #endif
-		printf(_("Mathomatic version %s (www.mathomatic.org)\n"), VERSION);
+		printf(_("This is Mathomatic version %s (www.mathomatic.org).\n"), VERSION);
 		printf(_("Copyright (C) 1987-2008 George Gesslein II.\n"));
 		printf(_("%d equation spaces available, %ldK per equation space.\n"),
 		    N_EQUATIONS, (long) n_tokens * sizeof(token_type) * 2L / 1000L);
@@ -204,17 +206,18 @@ char	**argv;
 static void
 usage()
 {
-	printf("Mathomatic version %s - automatic algebraic manipulator\n\n", VERSION);
-	printf("Usage: %s [ options ] [ input_files ]\n\n", prog_name);
-	printf("Options:\n");
-	printf("  -c            Toggle color mode.\n");
-	printf("  -h            Enable HTML output mode.\n");
-	printf("  -m number     Specify a memory size multiplier.\n");
-	printf("  -q            Set quiet mode (don't display prompts).\n");
-	printf("  -r            Disable readline.\n");
-	printf("  -t            Set test mode.\n");
-	printf("  -u            Set unbuffered output.\n");
-	printf("  -v            Display version number, compile flags, and memory usage.\n");
+	printf(_("Mathomatic version %s - automatic algebraic manipulator\n\n"), VERSION);
+	printf(_("Usage: %s [ options ] [ input_files ]\n\n"), prog_name);
+	printf(_("Options:\n"));
+	printf(_("  -c            Toggle color mode.\n"));
+	printf(_("  -h            Enable HTML output mode.\n"));
+	printf(_("  -m number     Specify a memory size multiplier.\n"));
+	printf(_("  -q            Set quiet mode (don't display prompts).\n"));
+	printf(_("  -r            Disable readline.\n"));
+	printf(_("  -t            Set test mode.\n"));
+	printf(_("  -u            Set unbuffered output.\n"));
+	printf(_("  -v            Display version number, etc., then exit.\n"));
+	printf(_("\nPlease refer to the man page for more information.\n"));
 	exit(2);
 }
 
@@ -350,7 +353,7 @@ int	sig;
 		break;
 	default:
 		/* abruptly quit this program */
-		printf(_("\nControl-C repeatedly pressed, quitting...\n"));
+		printf(_("\nControl-C repeatedly pressed; Quitting...\n"));
 		exit_program(1);
 	}
 }
