@@ -160,30 +160,6 @@ int		*np;		/* pointer to expression length */
 	}
 }
 
-/*
- * Parse an equation string into equation space "n".
- *
- * Returns the new string position or NULL on error.
- * Currently, there can be no more to parse in the string when this returns.
- */
-char	*
-parse_equation(n, cp)
-int	n;	/* equation space number */
-char	*cp;	/* pointer to the beginning of the equation character string */
-{
-	if (!case_sensitive_flag) {
-		str_tolower(cp);
-	}
-	if ((cp = parse_section(lhs[n], &n_lhs[n], cp)) != NULL) {
-		if ((cp = parse_section(rhs[n], &n_rhs[n], cp)) != NULL) {
-			if (extra_characters(cp))
-				return NULL;
-			return cp;
-		}
-	}
-	return NULL;
-}
-
 /*
  * This is a simple, non-recursive mathematical expression parser.
  * To parse, the character string is sequentially read and stored
@@ -227,7 +203,7 @@ char		*cp;		/* string to parse */
 		case '}':
 			cur_level--;
 			if (cur_level <= 0 || (abs_count > 0 && cur_level < abs_array[abs_count-1])) {
-				put_up_arrow((int) (cp - cp_start), _("Unmatched parenthesis: too many )"));
+				put_up_arrow(cp - cp_start, _("Unmatched parenthesis: too many )"));
 				return(NULL);
 			}
 			if (!operand) {
@@ -284,7 +260,7 @@ char		*cp;		/* string to parse */
 				goto syntax_error;
 			}
 			if (cp[1] == '!' && cp[2] != '!') {
-				warning(_("Multifactorial not implemented, using \"(x!)!\" for the factorial of x factorial."));
+				warning(_("Multifactorial not implemented, using x!! = (x!)!"));
 			}
 			equation[n].level = cur_level;
 			equation[n].kind = OPERATOR;
@@ -402,11 +378,10 @@ parse_power:
 			errno = 0;
 			d = strtod(cp1, &cp);
 			if (cp == cp1) {
-				put_up_arrow((int) (cp1 - cp_start), _("Error parsing constant."));
-				return(NULL);
+				goto syntax_error;
 			}
 			if (errno) {
-				put_up_arrow((int) (cp1 - cp_start), _("Constant out of range."));
+				put_up_arrow(cp1 - cp_start, _("Constant out of range."));
 				return(NULL);
 			}
 			equation[n].kind = CONSTANT;
@@ -417,7 +392,7 @@ parse_power:
 			break;
 		default:
 			if (!isvarchar(*cp)) {
-				put_up_arrow((int) (cp - cp_start), _("Unrecognized character."));
+				put_up_arrow(cp - cp_start, _("Unrecognized character."));
 				return(NULL);
 			}
 			if (!operand) {
@@ -451,7 +426,7 @@ p_out:
 		goto syntax_error;
 	}
 	if (cur_level != 1) {
-		put_up_arrow((int) (cp - cp_start), _("Unmatched parenthesis: missing )"));
+		put_up_arrow(cp - cp_start, _("Unmatched parenthesis: missing )"));
 		return(NULL);
 	}
 	while (*cp == '=')
@@ -466,10 +441,91 @@ p_out:
 	return cp;
 
 syntax_error:
-	put_up_arrow((int) (cp - cp_start), _("Syntax error."));
+	put_up_arrow(cp - cp_start, _("Syntax error."));
 	return(NULL);
 }
 
+/*
+ * Parse an equation string into equation space "n".
+ *
+ * Returns the new string position or NULL on error.
+ * Currently, there can be no more to parse in the string when this returns.
+ */
+char	*
+parse_equation(n, cp)
+int	n;	/* equation space number */
+char	*cp;	/* pointer to the beginning of the equation character string */
+{
+	if (!case_sensitive_flag) {
+		str_tolower(cp);
+	}
+	if ((cp = parse_section(lhs[n], &n_lhs[n], cp)) != NULL) {
+		if ((cp = parse_section(rhs[n], &n_rhs[n], cp)) != NULL) {
+			if (extra_characters(cp))
+				return NULL;
+			return cp;
+		}
+	}
+	return NULL;
+}
+
+/*
+ * Parse an expression with equation space pull if the line starts with "#" followed by an equation number.
+ *
+ * Returns the new string position or NULL on error.
+ * Currently, there can be no more to parse in the string when this returns.
+ */
+char	*
+parse_expr(equation, np, cp)
+token_type	*equation;	/* where the parsed expression is stored (equation side) */
+int		*np;		/* pointer to the returned parsed expression length */
+char		*cp;		/* string to parse */
+{
+	int	i;
+	char	*cp1, *cp2;
+
+	if (!case_sensitive_flag) {
+		str_tolower(cp);
+	}
+	cp1 = skip_space(cp);
+	if (*cp1 == '#') {
+		cp1++;
+		switch (*cp1) {
+		case '+':
+		case '-':
+			i = decstrtol(cp1, &cp2);
+			i = cur_equation + i;
+			break;
+		default:
+			i = decstrtol(cp1, &cp2) - 1;
+			break;
+		}
+		if (cp1 == cp2 || *cp2) {
+			error(_("Error parsing equation space number."));
+			return NULL;
+		}
+		if (i < 0 || i >= n_equations || n_lhs[i] <= 0) {
+			error(_("Equation not defined."));
+			return NULL;
+		}
+		if (n_rhs[i]) {
+			blt(equation, rhs[i], n_rhs[i] * sizeof(token_type));
+			*np = n_rhs[i];
+		} else {
+			blt(equation, lhs[i], n_lhs[i] * sizeof(token_type));
+			*np = n_lhs[i];
+		}
+		list_proc(equation, *np, false);
+		fprintf(gfp, "\n");
+		return cp2;
+	}
+	if ((cp = parse_section(equation, np, cp)) != NULL) {
+		if (extra_characters(cp))
+			return NULL;
+	}
+	return cp;
+}
+
 /*
  * Parse variable name string pointed to by "cp".
  * The variable name is converted to Mathomatic format and stored in "*vp".
@@ -655,10 +711,12 @@ double	*dp;
 {
 	switch (v) {
 	case V_E:
-		*dp = M_E;
+		if (dp)
+			*dp = M_E;
 		return true;
 	case V_PI:
-		*dp = M_PI;
+		if (dp)
+			*dp = M_PI;
 		return true;
 	}
 	return false;
