@@ -470,7 +470,7 @@ remove_factors()
 	debug_string(3, "Entering remove_factors() with:");
 	side_debug(3, tlhs, n_tlhs);
 	do {
-		simp_ssub(tlhs, &n_tlhs, 0L, 1.0, false, true, 0);
+		simp_ssub(tlhs, &n_tlhs, 0L, 1.0, false, true, 1 /* formerly 0 */);
 	} while (uf_power(tlhs, &n_tlhs));
 	for (i = 1, j = 0, k = 0;; i += 2) {
 		if (i >= n_tlhs) {
@@ -717,7 +717,6 @@ int		n;	/* length of expression */
 
 /*
  * This routine is a modulus (%) simplifier for equation sides.
- * It does polynomial division, so tlhs and trhs are wiped out.
  *
  * Return true if expression was modified.
  */
@@ -739,7 +738,6 @@ int		*np, loc, level;
 	int	i1, i2, i3, i4, i5;
 	int	op, last_op2;
 	int	len1, len2, len3;
-	long	v;
 	int	diff_sign;
 
 	for (i = loc; i < *np && equation[i].level >= level;) {
@@ -857,18 +855,20 @@ int		*np, loc, level;
 					}
 					break;
 				}
-				/* remove integer*n multiples in x for x%n by doing */
-				/* polynomial division and replacing with remainder%n */
-				v = 0;
+#if	false
+				/* Remove integer*n multiples in x for x%n by doing */
+				/* polynomial division and replacing with remainder%n. */
+				/* Currently gives wrong answers sometimes, */
+				/* for example x%(x^x) simplifies to 0. */
+				/* Globals tlhs[] and trhs[] are wiped out by the polynomial division here. */
+				long v = 0;
 				if (poly_div(&equation[j], len2, &equation[i+1], len1, &v)) {
 					if (is_integer_expr(tlhs, n_tlhs)) {
 						if ((*np + (n_trhs - len2)) > n_tokens)
 							error_huge();
-#if	!SILENT
 						if (var_count(tlhs, n_tlhs)) {
-							printf(_("Modulus simplification made some variables integer only.\n"));
+							warning("Modulus simplification made some variables integer only.");
 						}
-#endif
 						for (k = 0; k < n_trhs; k++)
 							trhs[k].level += level;
 						blt(&equation[j+n_trhs], &equation[j+len2], (*np - (j + len2)) * sizeof(token_type));
@@ -877,6 +877,7 @@ int		*np, loc, level;
 						return true;
 					}
 				}
+#endif
 			}
 		}
 	}
@@ -958,7 +959,7 @@ store_code:
 					blt(&equation[i+n_tlhs+1], &equation[i+1+len1], (*np - (i + 1 + len1)) * sizeof(token_type));
 					*np += n_tlhs - len1;
 					blt(&equation[i+1], tlhs, n_tlhs * sizeof(token_type));
-					debug_string(0, _("Division simplified with polynomial GCD."));
+					debug_string(1, _("Division simplified with polynomial GCD."));
 					modified = true;
 					goto start;
 				}
