@@ -71,7 +71,7 @@ long double	ceill(), sqrtl(), fmodl(), strtold();
 long double max_integer;		/* largest value of a long double integral value */
 long double start_value;		/* where to start finding primes */
 long double number;			/* number of primes to display */
-long double default_number = 40;	/* default number of primes to display */
+long double default_number = 30;	/* default number of primes to display */
 long double end_value;			/* where to stop finding primes */
 long double skip_multiples[] = {	/* Additive array that skips over multiples of 2, 3, 5, and 7. */
 	10, 2, 4, 2, 4, 6, 2, 6,
@@ -109,12 +109,12 @@ main(int argc, char *argv[])
 	} else if (sizeof(long double) == 8) {
 		max_integer = 1.0e14L;	/* 14 digits for doubles */
 	} else {
-		fprintf(stderr, "%s: Unsupported size of long double = %d bytes.\n", prog_name, sizeof(long double));
+		fprintf(stderr, "%s: Unsupported size of long double = %u bytes.\n", prog_name, sizeof(long double));
 		exit(2);
 	}
 	end_value = max_integer;
 	if (end_value == end_value + 1.0) {
-		fprintf(stderr, "Warning: max_integer is too large; size of long double = %d bytes.\n", sizeof(long double));
+		fprintf(stderr, "Warning: max_integer is too large; size of long double = %u bytes.\n", sizeof(long double));
 	}
 	number = 0;
 /* process command line options: */
