@@ -34,7 +34,7 @@ int		*np;		/* pointer to length of equation side */
 		longjmp(jmp_save, 13);
 	}
 	if (*np > n_tokens) {
-		error("Internal error: expression array overflow detected.");
+		error("Internal error: expression array overflow detected in organize().");
 		longjmp(jmp_save, 13);
 	}
 	org_recurse(equation, np, 0, 1, NULL);
@@ -174,6 +174,38 @@ int		*np;		/* pointer to length of equation side */
 	side_debug(5, equation, *np);
 }
 
+/*
+ * Configurable high level simplify routine.
+ */
+void
+simp_ssub(equation, np, v, d, power_flag, times_flag, fc_level)
+token_type	*equation;	/* pointer to the beginning of equation side to simplify */
+int		*np;		/* pointer to length of equation side */
+long		v;		/* variable to factor, 0L or MATCH_ANY to factor all variables */
+double		d;		/* factor expressions raised to the power of this if v */
+int		power_flag;	/* factor_power() flag */
+int		times_flag;	/* factor_times() flag */
+int		fc_level;	/* factor constants code, passed to factor_constants() */
+{
+	do {
+		do {
+			do {
+				do {
+					do {
+						do {
+							do {
+								do {
+									elim_loop(equation, np);
+								} while (simp2_power(equation, np));
+							} while (times_flag && factor_times(equation, np));
+						} while (elim_sign(equation, np));
+					} while (subtract_itself(equation, np));
+				} while (factor_constants(equation, np, fc_level));
+			} while (factor_divide(equation, np, v, d));
+		} while (factor_plus(equation, np, v, d));
+	} while (power_flag && factor_power(equation, np));
+}
+
 /*
  * Quickly and very basically simplify an equation space.
  * No factoring is done.
@@ -233,22 +265,48 @@ long		v;		/* variable to factor, 0 for all variables */
 
 /*
  * Convert expressions with any algebraic fractions into a single simple fraction.
- * Used by the fraction command.
+ * Used by the fraction and simplify commands.
+ *
+ * Globals tlhs[] and trhs[] are wiped out.
  */
 void
-frac_side(equation, np)
+simple_frac_side(equation, np)
 token_type	*equation;	/* pointer to the beginning of equation side */
 int		*np;		/* pointer to length of equation side */
 {
 	if (*np == 0)
 		return;
 	do {
-		simp_loop(equation, np);
-		uf_allpower(equation, np);
-		simp_ssub(equation, np, 0L, 1.0, false, true, 2);
+		do {
+			do {
+				simp_ssub(equation, np, 0L, 1.0, false, true, 2);
+			} while (poly_gcd_simp(equation, np));
+		} while (uf_power(equation, np));
 	} while (super_factor(equation, np, 2));
 }
 
+/*
+ * Factor only the specified variable "v".
+ * If v is IMAGINARY, do complex number simplification.
+ */
+void
+factorv(equation, np, v)
+token_type	*equation;	/* pointer to the beginning of equation side to factor */
+int		*np;		/* pointer to equation side length */
+long		v;		/* variable to factor */
+{
+	if (v == IMAGINARY) {
+		do {
+			elim_loop(equation, np);
+		} while (complex_root_simp(equation, np));
+	}
+	do {
+		do {
+			simp_loop(equation, np);
+		} while (factor_plus(equation, np, v, 0.0));
+	} while (v == IMAGINARY && div_imaginary(equation, np));
+}
+
 /*
  * Simplify and approximate for the calculate command and for more successful comparisons.
  * Includes complex number simplification.
@@ -320,144 +378,42 @@ int		*np;
 }
 
 /*
- * Main simplify code used by the simplify command.
- * This is the slowest and most thorough simplify of all.
- * Applies many equivalent algebraic transformations and their inverses (like unfactor and factor),
- * then does generalized polynomial simplifications.
- *
- * Globals tlhs[] and trhs[] are wiped out.
+ * Combine all like denominators.
  */
 void
-simpa_side(equation, np, quick_flag, frac_flag)
-token_type	*equation;	/* pointer to the beginning of equation side to simplify */
-int		*np;		/* pointer to length of the equation side */
-int		quick_flag;	/* "simplify quick" option, simpler fractions with no (x+1)^2 expansion */
-int		frac_flag;	/* "simplify fraction" option, simplify to the ratio of two polynomials */
+simp_divide(equation, np)
+token_type	*equation;
+int		*np;
 {
-	int		i;
-	int		flag, poly_flag = true;
-	jmp_buf		save_save;
-
-	if (*np <= 1)	/* no need to simplify a single constant or variable */
-		return;
-	side_debug(2, equation, *np);
-#if	true	/* polynomial factoring adds to processing time, but sometimes simplifies more */
-	simp_loop(equation, np);
-	poly_factor(equation, np);
-#endif
-	simpb_side(equation, np, true, 1);
-	simp_ssub(equation, np, 0L, 0.0, true, true, 1);
-	rationalize(equation, np);
-	unsimp_power(equation, np);
-	uf_times(equation, np);
-	simp_loop(equation, np);
-/* Here is the only place in Mathomatic that we do modulus (%) simplification: */
-	uf_repeat(equation, np);
 	do {
-		elim_loop(equation, np);
-	} while (mod_simp(equation, np));
-/* Here we try to simplify out unnecessary negative constants and imaginary numbers: */
-	simp_i(equation, np);
-	unsimp_power(equation, np);
-	uf_times(equation, np);
-	simp_ssub(equation, np, 0L, 1.0, true, true, 1);
-	unsimp_power(equation, np);
-	uf_neg_help(equation, np);
-	uf_times(equation, np);
+		do {
+			simp_loop(equation, np);
+		} while (factor_constants(equation, np, 1));
+	} while (factor_divide(equation, np, 0L, 0.0));
+}
+
+/*
+ * Combine all like denominators containing variable "v".
+ * Don't call factor_times().
+ */
+void
+simp2_divide(equation, np, v, fc_level)
+token_type	*equation;
+int		*np;
+long		v;
+int		fc_level;
+{
 	do {
 		do {
 			do {
-				simp_ssub(equation, np, 0L, 1.0, false, true, 1);
-			} while (poly_gcd_simp(equation, np));
-		} while (uf_power(equation, np));
-	} while (super_factor(equation, np, 2));
-	unsimp_power(equation, np);
-	uf_times(equation, np);
-	factorv(equation, np, IMAGINARY);
-	uf_pplus(equation, np);
-	simp_ssub(equation, np, 0L, 1.0, true, false, 1);
-	uf_times(equation, np);
-	uf_pplus(equation, np);
-	factorv(equation, np, IMAGINARY);
-	uf_power(equation, np);
-	do {
-		do {
-			simp_ssub(equation, np, 0L, 1.0, false, true, 1);
-		} while (uf_power(equation, np));
-	} while (super_factor(equation, np, 2));
-
-/* Here we do the greatest expansion; if it fails, do less expansion. */
-	partial_flag = frac_flag;
-	n_tlhs = *np;
-	blt(tlhs, equation, n_tlhs * sizeof(token_type));
-	blt(save_save, jmp_save, sizeof(jmp_save));
-	if ((i = setjmp(jmp_save)) != 0) {	/* trap errors */
-		blt(jmp_save, save_save, sizeof(jmp_save));
-		if (i == 13) {	/* critical error code */
-			longjmp(jmp_save, i);
-		}
-		/* an error occurred, restore the original expression */
-		*np = n_tlhs;
-		blt(equation, tlhs, n_tlhs * sizeof(token_type));
-		debug_string(1, "Simplify not expanding fully.");
-		partial_flag = true;	/* expand less */
-		uf_tsimp(equation, np);
-	} else {
-		if (quick_flag) {
-			uf_tsimp(equation, np);
-		} else {
-			/* expand powers of 2 and higher, might result in error_huge() trap */
-			do {
-				uf_repeat(equation, np);
-			} while (uf_tsimp(equation, np));
-		}
-		blt(jmp_save, save_save, sizeof(jmp_save));
-	}
-	partial_flag = true;
-
-	simpb_side(equation, np, true, 1);
-	debug_string(1, "Simplify result before applying polynomial operations:");
-	side_debug(1, equation, *np);
-	for (flag = false;;) {
-		/* divide top and bottom of fractions by any polynomial GCD found */
-		if (poly_gcd_simp(equation, np)) {
-			flag = false;
-			simpb_side(equation, np, true, 1);
-		}
-		if (!flag) {
-			/* factor polynomials */
-			if (poly_factor(equation, np)) {
-				flag = true;
-				simpb_side(equation, np, true, 1);
-				continue;
-			}
-		}
-		/* simplify algebraic fractions with polynomial and smart division */
-		if (!frac_flag && div_remainder(equation, np, poly_flag, quick_flag)) {
-			flag = false;
-			simpb_side(equation, np, true, 1);
-			continue;
-		}
-		break;
-	}
-	simpb_side(equation, np, true, 1);
-	simp_constant_power(equation, np);
-	simp_ssub(equation, np, /* 0L */ MATCH_ANY, 1.0, true, true, 1);
-	unsimp_power(equation, np);
-	make_fractions(equation, np);
-	factor_power(equation, np);
-	uf_tsimp(equation, np);
-	make_fractions(equation, np);
-	uf_power(equation, np);
-	integer_root_simp(equation, np);
-	simpb_side(equation, np, true, 3);
-	if (!frac_flag) {
-		while (div_remainder(equation, np, poly_flag, quick_flag)) {
-			simpb_side(equation, np, true, 3);
-		}
-	}
-	poly_factor(equation, np);
-	simpb_side(equation, np, true, 2);
+				do {
+					do {
+						elim_loop(equation, np);
+					} while (simp2_power(equation, np));
+				} while (elim_sign(equation, np));
+			} while (subtract_itself(equation, np));
+		} while (factor_constants(equation, np, fc_level));
+	} while (factor_divide(equation, np, v, 0.0));
 }
 
 /*
@@ -490,6 +446,7 @@ sort_type	*p1, *p2;
  * Neat simplify and factor routine.
  * Factors variables in order: "sign" variables first, then by frequency.
  */
+void
 simpb_side(equation, np, power_flag, fc_level)
 token_type	*equation;	/* pointer to the beginning of equation side */
 int		*np;		/* pointer to length of equation side */
@@ -502,11 +459,11 @@ int		fc_level;	/* factor constants code, passed to factor_constants() */
 	sort_type	va[MAX_VARS];
 
 	simp_loop(equation, np);
-#if	false
-	uf_power(equation, np);
-#else
-	uf_allpower(equation, np);
-#endif
+	if (true) {
+		uf_pplus(equation, np);
+	} else {
+		uf_allpower(equation, np);
+	}
 	last_v = 0;
 	for (vc = 0; vc < ARR_CNT(va); vc++) {
 		cnt = 0;
@@ -548,34 +505,132 @@ int		fc_level;	/* factor constants code, passed to factor_constants() */
 }
 
 /*
- * Configurable high level simplify routine.
+ * Main simplify code used by the simplify command.
+ * This is the slowest and most thorough simplify of all.
+ * Applies many equivalent algebraic transformations and their inverses (like unfactor and factor),
+ * then does generalized polynomial simplifications.
+ *
+ * Globals tlhs[] and trhs[] are wiped out.
  */
-simp_ssub(equation, np, v, d, power_flag, times_flag, fc_level)
+void
+simpa_side(equation, np, quick_flag, frac_flag)
 token_type	*equation;	/* pointer to the beginning of equation side to simplify */
-int		*np;		/* pointer to length of equation side */
-long		v;		/* variable to factor, 0L or MATCH_ANY to factor all variables */
-double		d;		/* factor expressions raised to the power of this if v */
-int		power_flag;	/* factor_power() flag */
-int		times_flag;	/* factor_times() flag */
-int		fc_level;	/* factor constants code, passed to factor_constants() */
+int		*np;		/* pointer to length of the equation side */
+int		quick_flag;	/* "simplify quick" option, simpler fractions with no (x+1)^2 expansion */
+int		frac_flag;	/* "simplify fraction" option, simplify to the ratio of two polynomials */
 {
+	int		i;
+	int		flag, poly_flag = true;
+	jmp_buf		save_save;
+
+	if (*np <= 1)	/* no need to simplify a single constant or variable */
+		return;
+	side_debug(2, equation, *np);
+	simpb_side(equation, np, true, 1);
+	rationalize(equation, np);
+	unsimp_power(equation, np);
+	uf_times(equation, np);
+	simp_loop(equation, np);
+/* Here is the only place in Mathomatic that we do modulus (%) simplification: */
+	uf_repeat(equation, np);
 	do {
-		do {
+		elim_loop(equation, np);
+	} while (mod_simp(equation, np));
+/* Here we try to simplify out unnecessary negative constants and imaginary numbers: */
+	simp_i(equation, np);
+	unsimp_power(equation, np);
+	uf_times(equation, np);
+	simp_ssub(equation, np, 0L, 1.0, true, true, 1);
+	unsimp_power(equation, np);
+	uf_neg_help(equation, np);
+	uf_times(equation, np);
+	simple_frac_side(equation, np);
+	unsimp_power(equation, np);
+	uf_times(equation, np);
+	factorv(equation, np, IMAGINARY);
+	uf_pplus(equation, np);
+	simp_ssub(equation, np, 0L, 1.0, true, false, 1);
+	uf_times(equation, np);
+	uf_pplus(equation, np);
+	factorv(equation, np, IMAGINARY);
+	uf_power(equation, np);
+	simple_frac_side(equation, np);
+
+/* Here we do the greatest expansion; if it fails, do less expansion. */
+	partial_flag = frac_flag;
+	n_tlhs = *np;
+	blt(tlhs, equation, n_tlhs * sizeof(token_type));
+	blt(save_save, jmp_save, sizeof(jmp_save));
+	if ((i = setjmp(jmp_save)) != 0) {	/* trap errors */
+		blt(jmp_save, save_save, sizeof(jmp_save));
+		if (i == 13) {	/* critical error code */
+			longjmp(jmp_save, i);
+		}
+		/* an error occurred, restore the original expression */
+		*np = n_tlhs;
+		blt(equation, tlhs, n_tlhs * sizeof(token_type));
+		debug_string(1, "Simplify not expanding fully.");
+		partial_flag = true;	/* expand less */
+		uf_tsimp(equation, np);
+	} else {
+		if (quick_flag) {
+			uf_tsimp(equation, np);
+		} else {
+			/* expand powers of 2 and higher, might result in error_huge() trap */
 			do {
-				do {
-					do {
-						do {
-							do {
-								do {
-									elim_loop(equation, np);
-								} while (simp2_power(equation, np));
-							} while (times_flag && factor_times(equation, np));
-						} while (elim_sign(equation, np));
-					} while (subtract_itself(equation, np));
-				} while (factor_constants(equation, np, fc_level));
-			} while (factor_divide(equation, np, v, d));
-		} while (factor_plus(equation, np, v, d));
-	} while (power_flag && factor_power(equation, np));
+				uf_power(equation, np);
+				uf_repeat(equation, np);
+			} while (uf_tsimp(equation, np));
+		}
+		blt(jmp_save, save_save, sizeof(jmp_save));
+	}
+	partial_flag = true;
+
+	simpb_side(equation, np, true, 3);
+	debug_string(1, "Simplify result before applying polynomial operations:");
+	side_debug(1, equation, *np);
+	for (flag = false;;) {
+		/* divide top and bottom of fractions by any polynomial GCD found */
+		if (poly_gcd_simp(equation, np)) {
+			flag = false;
+			simpb_side(equation, np, true, 3);
+		}
+		if (!flag) {
+			/* factor polynomials */
+			while (poly_factor(equation, np)) {
+				flag = true;
+				simpb_side(equation, np, true, 3);
+			}
+			if (flag) {
+				continue;
+			}
+		}
+		/* simplify algebraic fractions with polynomial and smart division */
+		if (!frac_flag && div_remainder(equation, np, poly_flag, quick_flag)) {
+			flag = false;
+			simpb_side(equation, np, true, 3);
+			continue;
+		}
+		break;
+	}
+	simpb_side(equation, np, true, 1);
+	simp_constant_power(equation, np);
+	simp_loop(equation, np);
+	unsimp_power(equation, np);
+	make_fractions(equation, np);
+	factor_power(equation, np);
+	uf_tsimp(equation, np);
+	make_fractions(equation, np);
+	uf_power(equation, np);
+	integer_root_simp(equation, np);
+	simpb_side(equation, np, true, 3);
+	if (!frac_flag) {
+		while (div_remainder(equation, np, poly_flag, quick_flag)) {
+			simpb_side(equation, np, true, 3);
+		}
+	}
+	poly_factor(equation, np);
+	simpb_side(equation, np, true, 2);
 }
 
 /*
@@ -606,64 +661,6 @@ int		*np;		/* pointer to length of equation side */
 	return rv;
 }
 
-/*
- * Factor only the specified variable "v".
- * If v is IMAGINARY, do complex number simplification.
- */
-factorv(equation, np, v)
-token_type	*equation;	/* pointer to the beginning of equation side to factor */
-int		*np;		/* pointer to equation side length */
-long		v;		/* variable to factor */
-{
-	if (v == IMAGINARY) {
-		do {
-			elim_loop(equation, np);
-		} while (complex_root_simp(equation, np));
-	}
-	do {
-		do {
-			simp_loop(equation, np);
-		} while (factor_plus(equation, np, v, 0.0));
-	} while (v == IMAGINARY && div_imaginary(equation, np));
-}
-
-/*
- * Combine all like denominators.
- */
-simp_divide(equation, np)
-token_type	*equation;
-int		*np;
-{
-	do {
-		do {
-			simp_loop(equation, np);
-		} while (factor_constants(equation, np, 1));
-	} while (factor_divide(equation, np, 0L, 0.0));
-}
-
-/*
- * Combine all like denominators containing variable "v".
- * Don't call factor_times().
- */
-simp2_divide(equation, np, v, fc_level)
-token_type	*equation;
-int		*np;
-long		v;
-int		fc_level;
-{
-	do {
-		do {
-			do {
-				do {
-					do {
-						elim_loop(equation, np);
-					} while (simp2_power(equation, np));
-				} while (elim_sign(equation, np));
-			} while (subtract_itself(equation, np));
-		} while (factor_constants(equation, np, fc_level));
-	} while (factor_divide(equation, np, v, 0.0));
-}
-
 /*
  * Convert (x^n)^m to x^(n*m).
  *
@@ -1064,7 +1061,7 @@ double	k2;	/* Operand 2; ignored for unary operators. */
 			d = INFINITY;
 		} else {
 			d = pow(*k1p, k2);
-			if (preserve_roots && !approximate_roots) {
+			if (preserve_surds && !approximate_roots) {
 				if (isfinite(k2) && fmod(k2, 1.0) != 0.0 && f_to_fraction(*k1p, &d1, &d2)) {
 					if (!f_to_fraction(d, &d1, &d2)) {
 						domain_check = false;
@@ -1138,7 +1135,7 @@ beginning:
 			if (calc((loc1 <= old_loc) ? NULL : &equation[loc1-1].token.operatr, &d1, op, d2)) {
 				if (op == POWER && !domain_check) {
 					if (!f_to_fraction(d2, &numerator, &denominator)) {	/* if irrational power */
-						if (!iflag || (preserve_roots && !approximate_roots))
+						if (!iflag || (preserve_surds && !approximate_roots))
 							return modified;
 						cv.re = d1;
 						cv.im = 0.0;
@@ -1566,6 +1563,8 @@ int		n2, l2, *diff_signp;
 				return true;
 			}
 			break;
+		case OPERATOR:
+			break;
 		}
 		return false;
 	}
