@@ -123,8 +123,10 @@ int		*rightnp;	/* pointer to length of RHS */
 		}
 		zsolve = true;
 	}
+#if	true
 	uf_power(tlhs, &n_tlhs);
 	uf_power(trhs, &n_trhs);
+#endif
 simp_again:
 	/* Make sure equation is a bit simplified. */
 	list_tdebug(2);
@@ -506,7 +508,7 @@ zero_simp:
 					if (inc_count > MAX_RAISE_POWER)
 						return false;
 #if	!SILENT
-					printf(_("Raising both equation sides to the power of %g and unfactoring...\n"), 1.0 / b1->token.constant);
+					printf(_("Raising both equation sides to the power of %.*g and unfactoring...\n"), precision, 1.0 / b1->token.constant);
 #endif
 					zero_solved = false;
 					qtries = 0;
@@ -781,7 +783,7 @@ long	v;	/* solve variable */
 		return false;
 #if	!SILENT
 	list_var(v, 0);
-	printf(_("Equation is a degree %.*g polynomial in %s.\n"), precision, high_power, var_str);
+	printf(_("Equation is a degree %.*g polynomial in (%s).\n"), precision, high_power, var_str);
 #endif
 	if (a1p > trhs && (a1p - 1)->token.operatr == MINUS)
 		opx1 = MINUS;
@@ -988,11 +990,7 @@ big_bbreak:
 	n_trhs = len;
 	simp_loop(trhs, &n_trhs);
 	list_tdebug(2);
-#if	true
 	uf_tsimp(trhs, &n_trhs);	/* don't unfactor result so much, just unfactor what will be unfactored anyway */
-#else
-	uf_simp(trhs, &n_trhs);		/* totally unfactor, usually faster but result may be unwanted */
-#endif
 	simps_side(trhs, &n_trhs, false);
 	list_tdebug(1);
 #if	!SILENT
@@ -1115,23 +1113,27 @@ int		*side2np;	/* pointer to the length of "side2p" */
 			fprintf(gfp, _("Applying inverse modulus of"));
 			break;
 		}
-		fprintf(gfp, " \"");
-		if (op == POWER)
-			fprintf(gfp, "1/(");
-		list_proc(operandp, operandn, false);
-		switch (op) {
-		case PLUS:
-			fprintf(gfp, _("\" from both sides of the equation:\n"));
-			break;
-		case MINUS:
-		case MODULUS:
-			fprintf(gfp, _("\" to both sides of the equation:\n"));
-			break;
-		case POWER:
-			fprintf(gfp, ")");
-		default:
-			fprintf(gfp, "\":\n");
-			break;
+		if (op == POWER && operandn == 1 && operandp->kind == CONSTANT) {
+			fprintf(gfp, " %.*g:\n", precision, 1.0 / operandp->token.constant);
+		} else {
+			fprintf(gfp, " \"");
+			if (op == POWER)
+				fprintf(gfp, "1/(");
+			list_proc(operandp, operandn, false);
+			switch (op) {
+			case PLUS:
+				fprintf(gfp, _("\" from both sides of the equation:\n"));
+				break;
+			case MINUS:
+			case MODULUS:
+				fprintf(gfp, _("\" to both sides of the equation:\n"));
+				break;
+			case POWER:
+				fprintf(gfp, ")");
+			default:
+				fprintf(gfp, "\":\n");
+				break;
+			}
 		}
 	}
 #endif
