@@ -451,10 +451,14 @@ do_repeat:
 		if (ii != 8) {	/* if true, only do useful expansions */
 			if (d1 > 100.0)	/* ignore exponents over 100 */
 				break;
-			if ((i - b1) > 1 && d1 > 2.0 && fmod(d1, 1.0) != 0.0)
-				break;
 			if ((i - b1) == 1 && equation[b1].kind != CONSTANT)
 				break;
+#if	false
+			if ((i - b1) > 1 && level1_plus_count(&equation[b1], (i - b1)) <= 0)
+				break;
+#endif
+			if ((i - b1) > 1 && d1 > 2.0 && fmod(d1, 1.0) != 0.0)
+				break;
 		}
 		d1 = ceil(d1) - 1.0;
 		d2 = d1 * ((i - b1) + 1.0);
